@@ -8,6 +8,8 @@ Created on Mon Mar  7 15:47:09 2022
 import warnings
 warnings.simplefilter(action='ignore', category=FutureWarning)
 
+import pandas
+pandas.options.mode.chained_assignment = None
 import pandas
 import numpy
 from math import ceil
@@ -75,8 +77,8 @@ def scdataMulti(df,
         present in the loaded dataframe.
 
     post_est : int, default None
-        an integer specifying the number of post-treatment periods
-        for which treatment effects have to be estimated for each treated unit.
+        an integer specifying the number of post-treatment periods for which treatment effects have to be estimated for each treated unit. If
+        effect = "unit" it indicates the number of periods over which the average post-treatment effect is computed.
 
     units_est : list, default None
         a list specifying the treated units for which treatment effects have to be estimated.
@@ -411,11 +413,12 @@ def scdataMulti(df,
 
         if post_est is not None:
             T1_last = treated_unit_T0 + post_est
-            treated_donors = data[numpy.invert(data['__ID'].isin(treated_post)) &
-                                              (data['__time'] < T1_last)]
+            treated_donors = data[(data['__ID'].isin(treated_post)) &
+                                  (data['__time'] < T1_last)]
             tr_donors_count = treated_donors[['__ID', '__Treatment']].groupby('__ID').sum()
             tr_donors_units = tr_donors_count[tr_donors_count['__Treatment'] == 0].index.values.tolist()
-            donors_units = donors_units + tr_donors_units
+            donors_units.extend(tr_donors_units)
+            donors_units = (list(set(donors_units)))
             donors_units.sort()
 
         # subset dataset selecting treated units and proper donors
