@@ -7,8 +7,11 @@ Created on Tue Aug 17 14:46:14 2021
 # Temporary code to suppress pandas FutureWarning
 import warnings
 warnings.simplefilter(action='ignore', category=FutureWarning)
+from statsmodels.tools.sm_exceptions import IterationLimitWarning
+warnings.filterwarnings("ignore", category=IterationLimitWarning)
 
 import pandas
+pandas.options.mode.chained_assignment = None
 import numpy
 from copy import deepcopy
 import multiprocessing as mp
@@ -46,8 +49,6 @@ def scpi(data,
          plot=False,
          w_bounds=None,
          e_bounds=None,
-         opt_dict_est=None,
-         opt_dict_inf=None,
          verbose=True,
          pass_stata=False):
 
@@ -151,18 +152,6 @@ def scpi(data,
         the quantification of out-of-sample uncertainty is skipped. It is possible to provide only the lower bound or
         the upper bound by filling the other column with NAs.
 
-    opt_dict_est : dict
-        a dictionary specifying the stopping criteria used by the underling optimizer (nlopt) for point estimation.
-        The default is a sequential quadratic programming (SQP) algorithm for nonlinearly constrained gradient-based
-        optimization ('SLSQP'). In case a lasso-type constraint is implemented, cvxpy is used for optimization.
-        More information on the stopping criteria can be obtained reading the official documentation at
-        https://www.cvxpy.org/. The default values are 'maxeval = 5000', 'xtol_rel = 1e-8', 'xtol_abs = 1e-8',
-        'ftol_rel = 1e-4', 'ftol_abs = 1e-4', 'tol_eq = 1e-8', and 'tol_ineq = 1e-8'.
-
-    opt_dict_inf : dict
-        same as above but for inference purposes. The default values are 'maxeval = 5000', 'xtol_rel = 1e-8',
-        'xtol_abs = 1e-8', 'ftol_rel = 1e-4', 'ftol_abs = 1e-4', 'tol_eq = 1e-8', and 'tol_ineq = 1e-8'.
-
     verbose : bool
         if True prints additional information in the console.
 
@@ -386,7 +375,7 @@ def scpi(data,
     if pass_stata is False and verbose:
         print("-----------------------------------------------")
         print("Estimating Weights...")
-    sc_pred = scest(df=data, w_constr=w_constr, V=V, opt_dict=opt_dict_est)
+    sc_pred = scest(df=data, w_constr=w_constr, V=V)
 
     ######################################
     # Retrieve processed data from scest
@@ -474,22 +463,14 @@ def scpi(data,
             zeros = numpy.zeros((T1, sum(K.iloc[1:, ])))
             P = pandas.DataFrame(numpy.c_[P, zeros])
 
-    if opt_dict_inf is not None:
-        if not isinstance(opt_dict_inf, dict):
-            raise Exception("The object opt_list_inf should be a dictionary!")
-
-    if opt_dict_est is not None:
-        if not isinstance(opt_dict_est, dict):
-            raise Exception("The object opt_list_est should be a dictionary!")
-
     if not isinstance(u_sigma, str):
         raise Exception("The object u_sigma should be of type character!")
     else:
         if u_sigma not in ['HC0', 'HC1', 'HC2', 'HC3']:
             raise Exception("Supported variance estimators are 'HC0','HC1','HC2','HC3'.")
 
-    if sims < 10:
-        raise Exception("The number of simulations needs to be larger or equal than 10!")
+    # if sims < 10:
+        # raise Exception("The number of simulations needs to be larger or equal than 10!")
 
     if w_bounds is not None:
         if not isinstance(w_bounds, (pandas.DataFrame, numpy.ndarray)):
@@ -620,7 +601,7 @@ def scpi(data,
 
         ##########################################################################
         # Prepare design matrix for in-sample uncertainty
-        ud0 = u_des_prep(B_dict[tr], C_dict[tr], u_order, u_lags, coig_data[tr],
+        ud0 = u_des_prep(B_dict[tr], C_dict[tr], u_order, 1, coig_data[tr],
                          T0_M[tr], M[tr], constant[tr], index_i, iw_dict[tr],
                          u_design, res_dict[tr])
 
@@ -858,11 +839,11 @@ def scpi(data,
             p_int = 1
         elif p == "L2":
             p_int = 2
-        elif p == "L1/L2":
+        elif p == "L1-L2":
             p_int = None
 
         vsig = scpi_in(sims, b_arr, Sigma_root, Q, P_na, J, KM, iota, w_lb_est,
-                       w_ub_est, p, p_int, Q_star, Q2_star, dire, lb, cores, opt_dict_inf, pass_stata, verbose)
+                       w_ub_est, p, p_int, Q_star, Q2_star, dire, lb, cores, pass_stata, verbose)
 
     if w_lb_est is True:
         w_lb = numpy.nanquantile(vsig[:, :len(P_na)], q=u_alpha / 2, axis=0)
@@ -900,9 +881,7 @@ def scpi(data,
         warnings.warn("For some of the simulations used to quantify in-sample uncertainty the solution of " +
                       "the optimization problem was not found! We suggest inspecting the magnitude of this issue " +
                       "by consulting the percentage of simulations that failed contained in " +
-                      "YOUR_SCPI_OBJECT_NAME.failed_sims." +
-                      "In case the number of unsuccessful simulations is high, you might want to consider " +
-                      "changing the stopping criteria of the algorithm through the option 'opt_list_inf'.")
+                      "YOUR_SCPI_OBJECT_NAME.failed_sims.")
 
     # PIs for w
     sc_l_0 = Y_post_fit + w_lb        # Left bound
@@ -915,10 +894,10 @@ def scpi(data,
     ######################################
     ######################################
 
-    if w_constr_inf[tr_units[0]]['p'] in ["L1/L2", "L2"]:
-        epsk = epskappaGet(P_na, rho_dict, beta, tr_units)
+    if w_constr_inf[tr_units[0]]['p'] in ["L1-L2", "L2"]:
+        epsk = epskappaGet(P, rho_dict, beta, tr_units, effect=sc_effect)
         epsk = pandas.DataFrame(epsk, index=w_lb.index)
-        epsk_j = epskappaGet(P_na, rho_dict, beta, tr_units, joint=True)
+        epsk_j = epskappaGet(P, rho_dict, beta, tr_units, effect=sc_effect, joint=True)
     else:
         epsk = pandas.DataFrame([0] * len(w_lb), index=w_lb.index)
         epsk_j = 0
@@ -1057,7 +1036,7 @@ def scpi(data,
     ####################################################
     # Simultaneous Prediction Intervals (for each unit)
 
-    if sc_effect == "unit_time":  # joint within unit
+    if sc_effect == "unit-time":  # joint within unit
         T1val = [v for v in T1.values()]
         ML, MU = simultaneousPredGet(vsig, T1val, len(P_na), iota, u_alpha,
                                      e_alpha, e_res_na, e_des_0_na, e_des_1,
